import webob

# TODO: would be nice to make middleware smarter so it could work with
# a streamed HTML body instead of serializing it out to body. That
# would complicate the middleware signicantly, however. We would for
# instance need to recalculate content_length ourselves.

class Middleware(object):
    def __init__(self, application):
        self.application = application

    def __call__(self, environ, start_response):
        req = webob.Request(environ)
        res = req.get_response(self.application)
        if not res.content_type.lower() in ['text/html', 'text/xml']:
            return res(environ, start_response)
        needed = environ.get('hurry.resource.needed', None)
        if needed is None:
            return res(environ, start_response)
        res.body = needed.render_topbottom_into_html(res.body)
        return res(environ, start_response)



from setuptools import setup, find_packages
import sys, os

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

long_description = (
    read('src', 'hurry', 'resource', 'README.txt')
    + '\n' +
    read('CHANGES.txt')
    + '\n' +
    'Download\n'
    '********\n'
    )

setup(
    name='hurry.resource',
    version='0.9',
    description="Flexible resources for web applications.",
    long_description=long_description,
    classifiers=[],
    keywords='',
    author='Martijn Faassen',
    author_email='faassen@startifact.com',
    license='ZPL 2.1',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    namespace_packages=['hurry'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'zope.interface',
        'zope.component',
        ],
    extras_require = dict(test=['WebOb'],
                          wsgi=['WebOb']),
    entry_points={},
    )
